@@ -1,4 +1,4 @@
-from .testdb import init_test_db, destroy_test_db
+from .spawndb import init_test_db, destroy_test_db
 
 __all__ = [
     'init_test_db',
